sqlibrist
=========




Requirements
============

- PyYAML
- psycopg2


Tutorial
========




Django integration
==================



Changelog
=========

0.0.6 django_sqlibrist moved to separate package and is importable in settings.py as "django_sqlibrist"